import { TimelineLite, TimelineMax, TweenLite, TweenMax, Ease } from 'gsap';
import 'imports-loader?define=>false!scrollmagic/scrollmagic/minified/plugins/debug.addIndicators.min.js';
import 'imports-loader?define=>false!scrollmagic/scrollmagic/minified/plugins/animation.velocity.min.js';
import 'imports-loader?define=>false!scrollmagic/scrollmagic/minified/plugins/animation.gsap.min.js';
export declare class ScrollMagic {
    private _controller;
    private _scenes;
    /**
     * Permits to construct a controller that controls animated scrolling scenes
     * @param container Selector or DOM object that will contains the scroll animation controller
     * @param isVertical If the animation are based on vertical scrolling or horizontal scrolling
     */
    constructor(container?: string | object, isVertical?: boolean);
    /**
     * Permits to add scenes to the controller
     * @param scenes Scene to add to the controller
     */
    AddScenes(scenes: Scene | Scene[]): void;
    /**
     * Destroy the controller and all scene indicators
     */
    Destroy(): void;
}
export declare class Scene {
    /** If indicators are enabled or not */
    static IndicatorsEnabled: boolean;
    private _scene;
    /**
     * Build a Scene
     * @param duration Scene scrolling duration
     * @param offset Offset for the trigger position
     * @param triggerEl Selector or DOM object for the trigger element
     * @param triggerHook Position of the trigger hook in relation to the viewport (between 0 and 1). "onEnter" = 1, "onCenter" = 0.5, "onLeave" = 0
     * @param reverse If the scene is reversed when scrolling up
     */
    constructor(duration?: number | string | Function, offset?: number, triggerEl?: string | object, triggerHook?: number | string, reverse?: boolean);
    /**
     * Do not use this function, use ScrollMagic.AddScenes instead
     * @param ctrl Scroll Magic Controller object
     */
    AddToController(ctrl: any): void;
    /**
     * Permits to add indicators for debugging
     * @param name Name of indicator (default: undefined)
     */
    AddIndicators(name?: string): Scene;
    /**
     * Permits to remove indicators
     */
    RemoveIndicators(): void;
    /**
     * Permits to set a GSAP built tween object on the scene
     * @param tween A GSAP Tween object
     */
    setTween(tween: TimelineLite | TimelineMax | TweenLite | TweenMax): Scene;
    /**
     * Permits to set a basic tween without using GSAP object
     * @param targetEl Selector of DOM Object
     * @param animation The tween parameters (animation settings)
     * @param duration Duration of the tween
     */
    setTween_Simple(targetEl: string | object, animation: any, duration?: number | object): Scene;
    /**
     * Permits to set a basic from to animation without using GSAP object
     * @param target Selector or DOM object that represents the target
     * @param duration Duration in second
     * @param from From object configuration
     * @param to To object configuration
     * @param ease The animation ease
     * @param repeat Number of times that animation should repeat after its first iteration
     * @param yoyo If true, every other repeat cycle will run in the opposite direction
     */
    setTween_FromTo(target: string | object, duration: number, from: any, to: any, ease?: Ease, repeat?: number, yoyo?: boolean): Scene;
    /**
     * Permits to set a basic to animation without using GSAP object
     * @param target Selector or DOM object that represents the target
     * @param duration Duration in second
     * @param to To object configuration
     * @param ease The animation ease
     * @param repeat Number of times that animation should repeat after its first iteration
     * @param yoyo If true, every other repeat cycle will run in the opposite direction
     */
    setTween_To(target: string | object, duration: number, to: any, ease?: Ease, repeat?: number, yoyo?: boolean): Scene;
    /**
     * Permits to set a basic from stagger from to animation without using GSAP object
     * @param target Selector or DOM object that represents the target
     * @param duration Duration in second
     * @param from From object configuration
     * @param to To object configuration
     * @param stagger Amount of time in seconds to stagger the start time of each tween (default: 0)
     * @param ease The animation ease
     * @param repeat Number of times that animation should repeat after its first iteration
     * @param yoyo If true, every other repeat cycle will run in the opposite direction
     */
    setTween_staggerFromTo(targets: string | any[], duration: number, from: any, to: any, stagger?: number, ease?: Ease, repeat?: number, yoyo?: boolean): Scene;
    /**
     * Permits to create a Velocity animation
     * @param animatedEls One or more DOM elements or a selector used as target of the animation
     * @param animation The animation object
     * @param duration Duration in ms
     * @param ease Easing
     */
    setVelocity(animatedEls: string | object, animation: any, duration?: number, ease?: Ease): Scene;
    /**
     * Permits to toggle class inside an animation
     * @param animatedEl Selector or DOM object that represent the animated element
     * @param classes Classes to toggle during animation ("classA classB ..." for multiple classes)
     */
    setClassToggle(animatedEl: string | object, classes: string): Scene;
    /**
     * Add a callback function when entering in the animation
     * @param f The callback (event) => {}
     */
    onEnter(f: Function): Scene;
    /**
     * Add a callback when leaving an animation
     * @param f The callback (event) => {}
     */
    onLeave(f: Function): Scene;
    /**
     * Add a callback when the animation is progressing
     * @param f The callback (event) => {}
     */
    onProgress(f: Function): Scene;
    /**
     * Permits to pin an object during the animation
     * @param animatedEl The element to pin
     * @param spacerClass Class of the spacer created for pinning
     * @param pushFollowers If true following elements will be "pushed" down for the duration of the pin, if false the pinned element will just scroll past them. Ignored, when duration is 0.
     */
    setPin(animatedEl: string | object, spacerClass?: string, pushFollowers?: boolean): Scene;
}
