"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var gsap_1 = require("gsap");
var ScrollMagicLib = require("scrollmagic");
require("imports-loader?define=>false!scrollmagic/scrollmagic/minified/plugins/debug.addIndicators.min.js"); // For debugging indicators
require("imports-loader?define=>false!scrollmagic/scrollmagic/minified/plugins/animation.velocity.min.js");
require("imports-loader?define=>false!scrollmagic/scrollmagic/minified/plugins/animation.gsap.min.js");
var util_1 = require("util");
var ScrollMagic = /** @class */ (function () {
    /**
     * Permits to construct a controller that controls animated scrolling scenes
     * @param container Selector or DOM object that will contains the scroll animation controller
     * @param isVertical If the animation are based on vertical scrolling or horizontal scrolling
     */
    function ScrollMagic(container, isVertical) {
        if (container === void 0) { container = window; }
        if (isVertical === void 0) { isVertical = true; }
        this._scenes = [];
        this._controller = new ScrollMagicLib.Controller({
            container: container,
            vertical: isVertical
        });
    }
    /**
     * Permits to add scenes to the controller
     * @param scenes Scene to add to the controller
     */
    ScrollMagic.prototype.AddScenes = function (scenes) {
        if (!Array.isArray(scenes)) {
            scenes = [scenes];
        }
        for (var i = 0; i < scenes.length; i++) {
            var scene = scenes[i];
            scene.AddToController(this._controller);
            this._scenes.push(scene);
        }
    };
    /**
     * Destroy the controller and all scene indicators
     */
    ScrollMagic.prototype.Destroy = function () {
        try {
            this._controller.destroy();
        }
        catch (error) {
            console.warn("Error on scrollmagic destroy: " + error);
            // At least remove indicators
            for (var i = 0; i < this._scenes.length; i++) {
                this._scenes[i].RemoveIndicators();
            }
        }
    };
    return ScrollMagic;
}());
exports.ScrollMagic = ScrollMagic;
var Scene = /** @class */ (function () {
    /**
     * Build a Scene
     * @param duration Scene scrolling duration
     * @param offset Offset for the trigger position
     * @param triggerEl Selector or DOM object for the trigger element
     * @param triggerHook Position of the trigger hook in relation to the viewport (between 0 and 1). "onEnter" = 1, "onCenter" = 0.5, "onLeave" = 0
     * @param reverse If the scene is reversed when scrolling up
     */
    function Scene(duration, offset, triggerEl, triggerHook, reverse) {
        if (duration === void 0) { duration = 0; }
        if (offset === void 0) { offset = 0; }
        if (triggerEl === void 0) { triggerEl = null; }
        if (triggerHook === void 0) { triggerHook = "onCenter"; }
        if (reverse === void 0) { reverse = true; }
        this._scene = new ScrollMagicLib.Scene({
            duration: duration,
            offset: offset,
            triggerElement: triggerEl,
            triggerHook: triggerHook,
            reverse: reverse
        });
    }
    //#region Basic Methods 
    /**
     * Do not use this function, use ScrollMagic.AddScenes instead
     * @param ctrl Scroll Magic Controller object
     */
    Scene.prototype.AddToController = function (ctrl) {
        this._scene.addTo(ctrl);
    };
    /**
     * Permits to add indicators for debugging
     * @param name Name of indicator (default: undefined)
     */
    Scene.prototype.AddIndicators = function (name) {
        if (name === void 0) { name = undefined; }
        if (Scene.IndicatorsEnabled) {
            if (util_1.isUndefined(name)) {
                this._scene.addIndicators();
            }
            else {
                this._scene.addIndicators({ name: name });
            }
        }
        return this;
    };
    /**
     * Permits to remove indicators
     */
    Scene.prototype.RemoveIndicators = function () {
        this._scene.removeIndicators();
    };
    //#endregion Basic Methods
    //#region Tween Usage
    /**
     * Permits to set a GSAP built tween object on the scene
     * @param tween A GSAP Tween object
     */
    Scene.prototype.setTween = function (tween) {
        this._scene.setTween(tween);
        return this;
    };
    /**
     * Permits to set a basic tween without using GSAP object
     * @param targetEl Selector of DOM Object
     * @param animation The tween parameters (animation settings)
     * @param duration Duration of the tween
     */
    Scene.prototype.setTween_Simple = function (targetEl, animation, duration) {
        if (duration === void 0) { duration = 1; }
        this._scene.setTween(targetEl, duration, animation);
        return this;
    };
    /**
     * Permits to set a basic from to animation without using GSAP object
     * @param target Selector or DOM object that represents the target
     * @param duration Duration in second
     * @param from From object configuration
     * @param to To object configuration
     * @param ease The animation ease
     * @param repeat Number of times that animation should repeat after its first iteration
     * @param yoyo If true, every other repeat cycle will run in the opposite direction
     */
    Scene.prototype.setTween_FromTo = function (target, duration, from, to, ease, repeat, yoyo) {
        if (ease === void 0) { ease = gsap_1.Linear.easeNone; }
        if (repeat === void 0) { repeat = 0; }
        if (yoyo === void 0) { yoyo = false; }
        to.ease = ease;
        to.yoyo = yoyo;
        to.repeat = repeat;
        this._scene = this._scene.setTween(gsap_1.TweenMax.fromTo(target, duration, from, to));
        return this;
    };
    /**
     * Permits to set a basic to animation without using GSAP object
     * @param target Selector or DOM object that represents the target
     * @param duration Duration in second
     * @param to To object configuration
     * @param ease The animation ease
     * @param repeat Number of times that animation should repeat after its first iteration
     * @param yoyo If true, every other repeat cycle will run in the opposite direction
     */
    Scene.prototype.setTween_To = function (target, duration, to, ease, repeat, yoyo) {
        if (ease === void 0) { ease = gsap_1.Linear.easeNone; }
        if (repeat === void 0) { repeat = 0; }
        if (yoyo === void 0) { yoyo = false; }
        to.ease = ease;
        to.yoyo = yoyo;
        to.repeat = repeat;
        this._scene = this._scene.setTween(gsap_1.TweenMax.to(target, duration, to));
        return this;
    };
    /**
     * Permits to set a basic from stagger from to animation without using GSAP object
     * @param target Selector or DOM object that represents the target
     * @param duration Duration in second
     * @param from From object configuration
     * @param to To object configuration
     * @param stagger Amount of time in seconds to stagger the start time of each tween (default: 0)
     * @param ease The animation ease
     * @param repeat Number of times that animation should repeat after its first iteration
     * @param yoyo If true, every other repeat cycle will run in the opposite direction
     */
    Scene.prototype.setTween_staggerFromTo = function (targets, duration, from, to, stagger, ease, repeat, yoyo) {
        if (stagger === void 0) { stagger = 0; }
        if (ease === void 0) { ease = gsap_1.Linear.easeNone; }
        if (repeat === void 0) { repeat = 0; }
        if (yoyo === void 0) { yoyo = false; }
        to.ease = ease;
        to.yoyo = yoyo;
        to.repeat = repeat;
        this._scene = this._scene.setTween(gsap_1.TweenMax.staggerFromTo(targets, duration, from, to, stagger));
        return this;
    };
    //#endregion Tween Usage
    //#region Other scroll magic methods
    /**
     * Permits to create a Velocity animation
     * @param animatedEls One or more DOM elements or a selector used as target of the animation
     * @param animation The animation object
     * @param duration Duration in ms
     * @param ease Easing
     */
    Scene.prototype.setVelocity = function (animatedEls, animation, duration, ease) {
        if (duration === void 0) { duration = 0; }
        if (ease === void 0) { ease = gsap_1.Linear.easeNone; }
        this._scene.setVelocity(animatedEls, animation, { duration: duration, easing: ease });
        return this;
    };
    /**
     * Permits to toggle class inside an animation
     * @param animatedEl Selector or DOM object that represent the animated element
     * @param classes Classes to toggle during animation ("classA classB ..." for multiple classes)
     */
    Scene.prototype.setClassToggle = function (animatedEl, classes) {
        this._scene = this._scene.setClassToggle(animatedEl, classes);
        return this;
    };
    /**
     * Add a callback function when entering in the animation
     * @param f The callback (event) => {}
     */
    Scene.prototype.onEnter = function (f) {
        this._scene.on("enter", f);
        return this;
    };
    /**
     * Add a callback when leaving an animation
     * @param f The callback (event) => {}
     */
    Scene.prototype.onLeave = function (f) {
        this._scene.on("leave", f);
        return this;
    };
    /**
     * Add a callback when the animation is progressing
     * @param f The callback (event) => {}
     */
    Scene.prototype.onProgress = function (f) {
        this._scene.on("progress", f);
        return this;
    };
    /**
     * Permits to pin an object during the animation
     * @param animatedEl The element to pin
     * @param spacerClass Class of the spacer created for pinning
     * @param pushFollowers If true following elements will be "pushed" down for the duration of the pin, if false the pinned element will just scroll past them. Ignored, when duration is 0.
     */
    Scene.prototype.setPin = function (animatedEl, spacerClass, pushFollowers) {
        if (spacerClass === void 0) { spacerClass = "scrollmagic-pin-spacer"; }
        if (pushFollowers === void 0) { pushFollowers = true; }
        this._scene = this._scene.setPin(animatedEl, { pushFollowers: pushFollowers, spacerClass: spacerClass });
        return this;
    };
    /** If indicators are enabled or not */
    Scene.IndicatorsEnabled = true;
    return Scene;
}());
exports.Scene = Scene;
// PATCH FOR ADDING MULTIPLE CLASSES
ScrollMagicLib._util.addClass = function _patchedAddClass(elem, classname) {
    if (classname) {
        if (elem.classList) {
            classname.split(' ').forEach(function _addCls(c) {
                elem.classList.add(c);
            });
        }
        else
            elem.className += ' ' + classname;
    }
};
ScrollMagicLib._util.removeClass = function _patchedRemoveClass(elem, classname) {
    if (classname) {
        if (elem.classList) {
            classname.split(' ').forEach(function _removeCls(c) {
                elem.classList.remove(c);
            });
        }
        else
            elem.className = elem.className.replace(new RegExp('(^|\b)' + classname.split(' ').join('|') + '(\b|$)', 'gi'), ' ');
    }
};
